@@ -1,21 +1,20 @@
-# ----------------------------------- Abnormal --------------------------------------------------- #
-from cpanlp.abnormal.winner_curse import *
-from cpanlp.abnormal.bubble import *
 # ----------------------------------- Account --------------------------------------------------- #
 from cpanlp.account.assets.asset import *
+from cpanlp.account.assets.fixedasset import *
 from cpanlp.account.assets.inventory import *
+from cpanlp.account.assets.investmentproperty import *
 ## ---------------- IntangibleAsset ---------------------- ##
 from cpanlp.account.assets.intangibleasset.intangibleasset import *
 from cpanlp.account.assets.intangibleasset.landuseright import *
 from cpanlp.account.assets.intangibleasset.goodwill import *
 from cpanlp.account.assets.intangibleasset.intellectualproperty import *
 from cpanlp.account.assets.intangibleasset.franchise import *
+from cpanlp.account.assets.intangibleasset.patent import *
 ## ---------------- FinancialAsset ---------------------- ##
 from cpanlp.account.assets.financialasset.financialasset import *
 from cpanlp.account.assets.financialasset.bankdeposit import *
 from cpanlp.account.assets.financialasset.stock import *
 from cpanlp.account.assets.financialasset.accountsreceivables import *
-from cpanlp.account.assets.investmentproperty import *
 from cpanlp.account.cashflow.cashflow import *
 from cpanlp.account.liabilities.liability import *
 from cpanlp.account.liabilities.financia_lliability import *
@@ -36,13 +35,17 @@ from cpanlp.business.capacity import *
 from cpanlp.contract.agreement.agreement import *
 from cpanlp.contract.agreement.framework_agreement import *
 from cpanlp.contract.agreement.acting_in_concert_agreement import *
-from cpanlp.contract.arrangement import *
-from cpanlp.contract.memorandum_of_understanding import *
 ## ---------------- FinancialInstrument ---------------------- ##
 from cpanlp.contract.financial_instrument.financial_instrument import *
 from cpanlp.contract.financial_instrument.futures import *
 from cpanlp.contract.financial_instrument.private_equity import *
 from cpanlp.contract.financial_instrument.option import *
+from cpanlp.contract.financial_instrument.bond import *
+from cpanlp.contract.financial_instrument.convertible_bond import *
+from cpanlp.contract.financial_instrument.senior_notes import *
+
+from cpanlp.contract.arrangement import *
+from cpanlp.contract.memorandum_of_understanding import *
 from cpanlp.contract.loan_contract import *
 from cpanlp.contract.labor_contract import *
 from cpanlp.contract.lease import *
@@ -54,17 +57,16 @@ from cpanlp.control.power import *
 from cpanlp.control.control import *
 from cpanlp.control.influence import *
 from cpanlp.control.owner import *
-# ----------------------------------- Culture --------------------------------------------------- #
-from cpanlp.culture.spirit.spirit import *
-from cpanlp.culture.spirit.entrepreneurship import *
-from cpanlp.culture.spirit.craftsmanship import *
-from cpanlp.culture.business_philosophy import *
+from cpanlp.control.interest import *
 # ----------------------------------- Decorator --------------------------------------------------- #
+from cpanlp.decorator.announce import *
+from cpanlp.decorator.audited import *
 from cpanlp.decorator.witheffects import *
 from cpanlp.decorator.estimate import *
 from cpanlp.decorator.futuretense import *
 from cpanlp.decorator.validator import *
 from cpanlp.decorator.importance import *
+from cpanlp.decorator.secret import *
 # ----------------------------------- Department --------------------------------------------------- #
 from cpanlp.department.department import *
 from cpanlp.department.board_of_directors import *
@@ -84,19 +86,6 @@ from cpanlp.entity.partnership import *
 from cpanlp.entity.conglomerate.associatecompany import *
 from cpanlp.entity.conglomerate.jointventure import *
 from cpanlp.entity.conglomerate.subsidiary import *
-# ----------------------------------- EconomicSystem --------------------------------------------------- #
-from cpanlp.economic_system.economic_system import *
-from cpanlp.economic_system.financial_system import *
-from cpanlp.economic_system.physical_economy import *
-from cpanlp.economic_system.digital_economy import *
-from cpanlp.economic_system.market_economy import *
-from cpanlp.economic_system.planned_economy import *
-# ----------------------------------- Environment --------------------------------------------------- #
-from cpanlp.environment.environment import *
-from cpanlp.environment.market_environment import *
-from cpanlp.environment.economic_environment import *
-from cpanlp.environment.industry_environment import *
-from cpanlp.environment.credit_environment import *
 # ----------------------------------- Event --------------------------------------------------- #
 ## ---------------- Acquisition ---------------------- ##
 from cpanlp.event.acquisition.acquisition import *
@@ -140,20 +129,12 @@ from cpanlp.event.lawsuit import *
 from cpanlp.event.winning_bid import *
 # ----------------------------------- Incentive --------------------------------------------------- #
 from cpanlp.incentive.incentive import *
-# ----------------------------------- Information --------------------------------------------------- #
-from cpanlp.information.signal import *
-from cpanlp.information.information import *
-from cpanlp.information.speculative_information import *
-from cpanlp.information.asymmetric_information import *
 # ----------------------------------- Institution --------------------------------------------------- #
 from cpanlp.institution.institution import *
 # ----------------------------------- Market --------------------------------------------------- #
 from cpanlp.market.commodity import *
 from cpanlp.market.market import *
 from cpanlp.market.goods import *
-from cpanlp.market.structure.monopoly import *
-from cpanlp.market.structure.oligopoly import *
-from cpanlp.market.structure.perfectlycompetitive import *
 # ----------------------------------- Person --------------------------------------------------- #
 from cpanlp.person.consumer import *
 from cpanlp.person.craftsman import *
@@ -168,6 +149,7 @@ from cpanlp.person.investor.shareholder import *
 from cpanlp.person.investor.major_shareholder import *
 from cpanlp.person.investor.controlling_shareholder import *
 from cpanlp.person.investor.nominee_shareholder import *
+from cpanlp.person.investor.consenting_investor import *
 from cpanlp.person.guarantor import *
 from cpanlp.person.directors_supervisors_and_senior_executives.manager import *
 from cpanlp.person.partner import *
@@ -216,9 +198,25 @@ from cpanlp.strategy.strategy.strategy import *
 from cpanlp.strategy.strategy.financial_strategy import *
 from cpanlp.strategy.strategy.long_term_strategy import *
 # ----------------------------------- Tax --------------------------------------------------- #
+## ---------------- Behavior Tax ---------------------- ##
+from cpanlp.tax.behavior_tax import *
+from cpanlp.tax.transaction_tax import *
+## ---------------- Income Tax ---------------------- ##
+from cpanlp.tax.income_tax import *
+from cpanlp.tax.personal_income_tax import *
+from cpanlp.tax.corporate_income_tax import *
+## ---------------- Property Tax ---------------------- ##
+from cpanlp.tax.property_tax import *
+from cpanlp.tax.real_estate_tax import *
+## ---------------- Tax ---------------------- ##
 from cpanlp.tax.tax import *
+## ---------------- Trunover Tax ---------------------- ##
+from cpanlp.tax.turnover_tax import *
+from cpanlp.tax.VAT import *
+from cpanlp.tax.consumption_tax import *
 # ----------------------------------- Team --------------------------------------------------- #
 from cpanlp.team.team import *
+from cpanlp.team.reasearchteam import *
 # ----------------------------------- Utility --------------------------------------------------- #
 from cpanlp.utility.utility import *
 from cpanlp.params import *
