@@ -1,7 +1,7 @@
-from cpanlp.contract.financial_instrument.financial_instrument import *
-class ConvertibleBond(FinancialInstrument):
-    def __init__(self, issuer=None, coupon=None, conversion_price=None, maturity_date=None,parties=None, consideration=None,obligations=None, value=None):
-        super().__init__(parties, consideration,obligations, value)
+from cpanlp.contract.financial_instrument.bond import *
+class ConvertibleBond(Bond):
+    def __init__(self, issuer=None, coupon=None, conversion_price=None, maturity_date=None,parties=None, consideration=None,obligations=None, value=None,rate=None,currency=None,domestic=None,date=None,outstanding_balance=None):
+        super().__init__(parties,value, rate, currency,domestic,date,consideration, obligations,outstanding_balance)
         self.issuer = issuer
         self.coupon = coupon
         self.conversion_price = conversion_price
